<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Aturan;
use App\Models\Gejala;
use App\Models\Penyakit;

class AturanController extends Controller
{
    public function index()
    {
        $aturan = Aturan::with(['gejala', 'penyakit'])->get(); // <-- ini penting
        $gejala = Gejala::all();
        $penyakit = Penyakit::all();

        return view('admin.aturan', compact('aturan', 'gejala', 'penyakit'));
    }


    public function store(Request $request)
    {   
        $request->validate([
            'gejala_kode' => 'required|exists:gejala,kode',
            'penyakit_kode' => 'required|exists:penyakit,kode',
            'cf_pakar' => 'required|numeric|between:0,1'
        ]);

        Aturan::create([
            'gejala_kode' => $request->gejala_kode,
            'penyakit_kode' => $request->penyakit_kode,
            'cf_pakar' => $request->cf_pakar,
        ]);

        return redirect()->route('admin.aturan')->with('success', 'Aturan berhasil ditambahkan.');
    }
    public function destroy($id)
    {
        $aturan = Aturan::findOrFail($id);
        $aturan->delete();

        return redirect()->route('admin.aturan')->with('success', 'Aturan berhasil dihapus.');
    }
    public function edit($id)
    {
        $aturan = Aturan::findOrFail($id);
        $gejala = Gejala::all();
        $penyakit = Penyakit::all();

        return view('admin.editaturan', compact('aturan', 'gejala', 'penyakit'));
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'gejala_kode' => 'required|exists:gejala,kode',
            'penyakit_kode' => 'required|exists:penyakit,kode',
            'cf_pakar' => 'required|numeric|between:0,1'
        ]);

        $aturan = Aturan::findOrFail($id);
        $aturan->update([
            'gejala_kode' => $request->gejala_kode,
            'penyakit_kode' => $request->penyakit_kode,
            'cf_pakar' => $request->cf_pakar,
        ]);

        return redirect()->route('admin.aturan')->with('success', 'Aturan berhasil diperbarui.');
    }

}
