@extends('layouts.admin')

@section('content')
<div class="container">
    <h3 class="mb-4">Basis Pengetahuan (Aturan Diagnosa)</h3>

    @if(session('success'))
        <div class="alert alert-success">{{ session('success') }}</div>
    @endif

    <button class="btn btn-primary mb-3" data-bs-toggle="modal" data-bs-target="#addModal">+ Tambah Aturan</button>

    @if($aturan->isEmpty())
        <div class="alert alert-info">Belum ada data aturan.</div>
    @else
    <table class="table table-bordered table-striped bg-white text-dark">
        <thead class="table-light">
            <tr>
                <th>No</th>
                <th>Gejala</th>
                <th>Penyakit</th>
                <th>CF Pakar</th>
                <th>Aksi</th>
            </tr>
        </thead>
        <tbody>
            @foreach ($aturan as $i => $a)
            <tr>
                <td>{{ $i + 1 }}</td>
                <td>{{ $a->gejala->kode ?? '-' }} - {{ $a->gejala->nama_gejala ?? '' }}</td>
                <td>{{ $a->penyakit->kode ?? '-' }} - {{ $a->penyakit->nama_penyakit ?? '' }}</td>
                <td>{{ $a->cf_pakar }}</td>
                <td>
                    <form action="{{ route('admin.aturan.destroy', $a->id) }}" method="POST" onsubmit="return confirm('Yakin ingin menghapus aturan ini?')">
                        @csrf
                        @method('DELETE')
                        <a href="{{ route('admin.aturan.edit', $a->id) }}" class="btn btn-sm btn-warning">Edit</a>
                        <button class="btn btn-sm btn-danger">Hapus</button>
                    </form>
                </td>
            </tr>
            @endforeach
        </tbody>
    </table>
    @endif
</div>

<!-- Modal Tambah -->
<div class="modal fade" id="addModal" tabindex="-1" aria-labelledby="addModalLabel" aria-hidden="true">
  <div class="modal-dialog">
    <form action="{{ route('admin.aturan.store') }}" method="POST">
      @csrf
      <div class="modal-content">
        <div class="modal-header">
          <h5 class="modal-title" id="addModalLabel">Tambah Aturan</h5>
          <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
        </div>
        <div class="modal-body">
          <div class="mb-3">
            <label for="gejala_kode" class="form-label">Gejala</label>
            <select name="gejala_kode" class="form-select" required>
              @foreach($gejala as $g)
                <option value="{{ $g->kode }}">{{ $g->kode }} - {{ $g->nama_gejala }}</option>
              @endforeach
            </select>
          </div>
          <div class="mb-3">
            <label for="penyakit_kode" class="form-label">Penyakit</label>
            <select name="penyakit_kode" class="form-select" required>
              @foreach($penyakit as $p)
                <option value="{{ $p->kode }}">{{ $p->kode }} - {{ $p->nama_penyakit }}</option>
              @endforeach
            </select>
          </div>  
          <div class="mb-3">
            <label for="cf_pakar" class="form-label">CF Pakar (1–4)</label>
            <select name="cf_pakar" class="form-select" required>
              <option value="0.25">1 (0.25)</option>
              <option value="0.5">2 (0.50)</option>
              <option value="0.75">3 (0.75)</option>
              <option value="1">4 (1.00)</option>
            </select>
          </div>
        </div>
        <div class="modal-footer">
          <button type="submit" class="btn btn-success">Simpan</button>
        </div>
      </div>
    </form>
  </div>
</div>
@endsection
