@extends('layouts.admin')

@section('content')
<div class="container py-4">
    <h3 class="mb-4">Manajemen Solusi Penyakit</h3>

    @if(session('success'))
        <div class="alert alert-success">{{ session('success') }}</div>
    @endif

    <button class="btn btn-primary mb-3" data-bs-toggle="modal" data-bs-target="#addModal">+ Tambah Solusi</button>

    @if($solusi->isEmpty())
        <div class="alert alert-info">Belum ada data solusi.</div>
    @else
    <table class="table table-bordered bg-white text-dark">
        <thead class="table-light">
            <tr>
                <th>No</th>
                <th>Penyakit</th>
                <th>Metode Pengendalian</th>
                <th>Rekomendasi Pupuk</th>
                <th>Dosis per Tanaman</th>
                <th>Dosis per Hektar</th>
                <th>Waktu & Cara Aplikasi</th>
                <th>Aksi</th>
            </tr>
        </thead>
        <tbody>
            @foreach($solusi as $i => $s)
            <tr>
                <td>{{ $i + 1 }}</td>
                <td>{{ $s->penyakit->kode ?? '-' }} - {{ $s->penyakit->nama_penyakit ?? '' }}</td>
                <td>{{ $s->metode_pengendalian }}</td>
                <td>{{ $s->rekomendasi_pupuk }}</td>
                <td>{{ $s->dosis_tanaman }}</td>
                <td>{{ $s->dosis_hektar }}</td>
                <td>{{ $s->waktu_cara_aplikasi }}</td>
                <td>
                    <form action="{{ route('admin.solusi.destroy', $s->id) }}" method="POST" onsubmit="return confirm('Yakin ingin menghapus data ini?')">
                        @csrf
                        @method('DELETE')
                        <a href="{{ route('admin.solusi.edit', $s->id) }}" class="btn btn-warning btn-sm">Edit</a>
                        <button class="btn btn-danger btn-sm">Hapus</button>
                    </form>
                </td>
            </tr>
            @endforeach
        </tbody>
    </table>
    @endif
</div>

<!-- Modal Tambah -->
<div class="modal fade" id="addModal" tabindex="-1" aria-labelledby="addModalLabel" aria-hidden="true">
  <div class="modal-dialog">
    <form method="POST" action="{{ route('admin.solusi.store') }}">
        @csrf
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Tambah Solusi</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <div class="mb-3">
                    <label for="penyakit_kode" class="form-label">Pilih Penyakit</label>
                    <select name="penyakit_kode" class="form-select" required>
                        @foreach($penyakit as $p)
                        <option value="{{ $p->kode }}">{{ $p->kode }} - {{ $p->nama_penyakit }}</option>
                        @endforeach
                    </select>
                </div>
                <div class="mb-3">
                    <label for="metode_pengendalian" class="form-label">Metode Pengendalian</label>
                    <textarea name="metode_pengendalian" class="form-control" rows="3" required></textarea>
                </div>
                <div class="mb-3">
                    <label for="rekomendasi_pupuk" class="form-label">Rekomendasi Pupuk</label>
                    <input type="text" name="rekomendasi_pupuk" class="form-control" required>
                </div>
                <div class="mb-3">
                    <label for="dosis_tanaman" class="form-label">Dosis per Tanaman</label>
                    <input type="text" name="dosis_tanaman" class="form-control" required>
                </div>
                <div class="mb-3">
                    <label for="dosis_hektar" class="form-label">Dosis per Hektar</label>
                    <input type="text" name="dosis_hektar" class="form-control" required>
                </div>
                <div class="mb-3">
                    <label for="waktu_cara_aplikasi" class="form-label">Waktu & Cara Aplikasi</label>
                    <textarea name="waktu_cara_aplikasi" class="form-control" rows="3" required></textarea>
                </div>
            </div>
            <div class="modal-footer">
                <button type="submit" class="btn btn-success">Simpan</button>
            </div>
        </div>
    </form>
  </div>
</div>
@endsection
