@extends('layouts.user')

@section('content')
    <link rel="stylesheet" href="{{ asset('css/auth/hasil.css') }}">

    <div class="content">
        <a href="{{ url()->previous() }}"
            class="btn btn-light rounded-circle shadow-sm d-inline-flex align-items-center justify-content-center"
            style="width: 36px; height: 36px; position: absolute; top: 20px; left: 20px;">
            &#8592;
        </a>

        <h2>Detail Riwayat Diagnosa</h2>

        <div class="card mt-3">
            <div class="card-header bg-success text-white">
                <h4 class="mb-0">Penyakit Terduga</h4>
            </div>
            <div class="card-body">
                <p><strong>Tanggal Diagnosa:</strong> {{ \Carbon\Carbon::parse($riwayat->created_at)->format('d-m-Y H:i') }}
                </p>

                @php
                    $penyakitUnik = $riwayat->detail->groupBy('penyakit_kode')->take(2);
                @endphp

                @forelse($penyakitUnik as $kode => $detailGroup)
                    @php
                        $penyakit = $detailGroup->first()->penyakit;
                        $cf = $detailGroup->first()->cf_tertinggi;
                    @endphp

                    <div class="border-bottom mb-3 pb-2">
                        <p><strong>Kode Penyakit:</strong> {{ $penyakit->kode ?? '-' }}</p>
                        <p><strong>Nama Penyakit:</strong> {{ $penyakit->nama_penyakit ?? '-' }}</p>
                        <p><strong>Deskripsi:</strong> {{ $penyakit->deskripsi ?? '-' }}</p>
                        <p><strong>Tingkat Kepastian:</strong>
                            {{ number_format($cf, 2, ',', '.') }}%
                        </p>
                    </div>
                @empty
                    <p class="text-danger">Data penyakit tidak tersedia.</p>
                @endforelse
            </div>
        </div>

        @if ($penyakitUnik->count())
            @foreach ($penyakitUnik as $kode => $detailGroup)
                @php
                    $penyakit = $detailGroup->first()->penyakit;
                @endphp

                @if ($penyakit && $penyakit->solusi && $penyakit->solusi->count())
                    <div class="card mt-3">
                        <div class="card-header bg-info text-white">
                            <h4 class="mb-0">Solusi Penanganan untuk {{ $penyakit->nama_penyakit }}</h4>
                        </div>
                        <div class="card-body">
                            @foreach ($penyakit->solusi as $solusi)
                                <table class="table-solusi mb-4">
                                    <tbody>
                                        <tr>
                                            <th>Metode Pengendalian:</th>
                                            <td>{{ $solusi->metode_pengendalian }}</td>
                                        </tr>
                                        <tr>
                                            <th>Rekomendasi Pupuk:</th>
                                            <td>{{ $solusi->rekomendasi_pupuk }}</td>
                                        </tr>
                                        <tr>
                                            <th>Dosis Tanaman:</th>
                                            <td>{{ $solusi->dosis_tanaman }}</td>
                                        </tr>
                                        <tr>
                                            <th>Dosis per Hektar:</th>
                                            <td>{{ $solusi->dosis_hektar }}</td>
                                        </tr>
                                        <tr>
                                            <th>Waktu & Cara Aplikasi:</th>
                                            <td>{{ $solusi->waktu_cara_aplikasi }}</td>
                                        </tr>
                                    </tbody>
                                </table>
                            @endforeach
                        </div>
                    </div>
                @else
                    <div class="alert alert-warning mt-3">Belum ada solusi yang tersedia untuk penyakit
                        <strong>{{ $penyakit->nama_penyakit ?? '-' }}</strong>.</div>
                @endif
            @endforeach
        @endif

        <a href="{{ route('riwayat.cetak', $riwayat->id) }}" class="btn btn-danger mt-4 me-2">
            <i class="bi bi-file-earmark-pdf-fill"></i> Download PDF
        </a>
    </div>
@endsection
